@@ -47,22 +47,17 @@ lsmeans = function(object, specs, adjust=c("auto","tukey","sidak",p.adjust.metho
     ddfm = adjV = NULL
     
 # Figure out thecall (fixed effects part of model), bhat (=coefs), contrasts attr
-    if (inherits(object, "mer")) {
-        if(dim(object@V)[1] > 0) ### gradient matrix is nontrivial only for nonlinear models
-            stop("Can't handle an 'nlmer' model")
+    if (inherits(object, "mer") || inherits(object, "merMod")) {
+        if(!isLMM(object)) 
+            stop("Can't handle a nonlinear mixed model")
         thecall = slot(object, "call")
         bhat = fixef(object)
         contrasts = attr(model.matrix(object), "contrasts")
-        if (length(object@muEta) == 0) { # no glm's allowed...
-    ### Would really rather use below instead, but pbkrtest won't cooperate w/ any glm right now
-    ###   fam = object@call$family
-    ###   if (!is.null(fam) && !(fam %in% c("binomial", "poisson")))
-            if (require("pbkrtest")) {
-                adjV = vcovAdj(object, 0)
-                ddfm = function(k, se) .KRdf.mer (adjV, V, k, se*se)
-            }
-            else warning("Install package 'pbkrtest' to obtain bias corrections and degrees of freedom")
+        if (require("pbkrtest")) {
+            adjV = vcovAdj(object, 0)
+            ddfm = function(k, se) .KRdf.mer (adjV, V, k, se*se)
         }
+        else warning("Install package 'pbkrtest' to obtain bias corrections and degrees of freedom")
     }
     else if (inherits(object, "lme")) {
         thecall = object$call
