@@ -4,7 +4,7 @@ options(warn = 1)
 options(pager = "console")
 library('lsmeans')
 
-assign(".oldSearch", search(), pos = 'CheckExEnv')
+base::assign(".oldSearch", base::search(), pos = 'CheckExEnv')
 cleanEx()
 nameEx("fiber")
 ### * fiber
@@ -32,7 +32,7 @@ flush(stderr()); flush(stdout())
 
 ### Name: lsmeans
 ### Title: Least-squares means
-### Aliases: lsmeans print.lsm print.data.frame.lsm
+### Aliases: lsmeans print.lsm print.data.frame.lsm lsm glht.lsmlf
 ### Keywords: models regression htest
 
 ### ** Examples
@@ -70,15 +70,38 @@ if (require(pbkrtest)) {
   lsmeans(Oats.lmer, list(poly ~ nitro, pairwise ~ Variety))
 }
 
-# Use glht (multcomp) to do comparisons (note -- this does not use adjusted vcov)
+# Using in conjunction with 'glht' (note -- this does not use adjusted vcov)
 if (require(multcomp)) {
-  lsmeans(Oats.lmer, pairwise ~ Variety, glhargs=list(df=9.5))
+  # calling 'glht' from 'lsmeans' ...
+  lsmeans(Oats.lmer, pairwise ~ Variety, glhargs=list(df=9))
+  
+  # calling 'lsmeans' from 'glht' to get simultaneous CIs
+  confint(glht(Oats.lmer, linfct = lsm(~ Variety), df=9))
 }
 
 # Custom contrasts
 lsmeans(Oats.lmer, my.own ~ Variety, 
   contr = list(my.own = list(G.vs.M = c(1,-1,0), GM.vs.V = c(.5,.5,-1))))
+  
+#### Examples with trends...
+# Model with interaction
+fiber.lm2 = lm(strength ~ diameter * machine, data = fiber)
+# Compare the linear trends for diameter
+lsmeans(fiber.lm2, pairwise ~ machine, trend = "diameter")
 
+# Model with log(diameter) as the covariate
+fiber.lm3 = lm(strength ~ log(diameter) * machine, data = fiber)
+# Compare the fitted linear trends for log(diameter)
+lsmeans(fiber.lm3, pairwise ~ machine, trend = "log(diameter)")
+
+# Compare the fitted linear trends for diameter itself 
+# - this is done via a diff quotient - compare with fiber.lm2 results
+lsmeans(fiber.lm3, pairwise ~ machine, trend = "diameter")
+
+# Examine the linear functions generated for these examples
+lsmeans(fiber.lm2, ~ machine, trend = "diameter", lf = TRUE)
+lsmeans(fiber.lm3, ~ machine, trend = "log(diameter)", lf = TRUE)
+lsmeans(fiber.lm3, ~ machine, trend = "diameter", lf = TRUE)
 
 
 
@@ -142,7 +165,7 @@ poly.lsmc(1:4)
 
 ### * <FOOTER>
 ###
-cat("Time elapsed: ", proc.time() - get("ptime", pos = 'CheckExEnv'),"\n")
+base::cat("Time elapsed: ", proc.time() - base::get("ptime", pos = 'CheckExEnv'),"\n")
 grDevices::dev.off()
 ###
 ### Local variables: ***
